local StoneGate = ...

-- Apply building asset processor
StoneGate:registerAssetProcessor("models/stoneDecoration/corner.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
-- Register Corner materials
StoneGate:registerAssetId("models/stoneDecoration/corner.fbx/Materials/whiteStoneFrame", _CommonWindowPrefix .. "_CORNER_WHITE_STONE_FRAME_MATERIAL")

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	StoneGate:registerAsset({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
                IsVisibleWhenBuilt = false, -- to mask the green diamond in top, only visible in preview
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0*_NoSandbox }
		    },
		    ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 0*_NoSandbox }
		    }}
	        }
	})
end

-- Register Corner prefab nodes
StoneGate:registerAssetId("models/stoneDecoration/corner.fbx/Prefab/corner/step_3_Corner_TopPart", _CommonWindowPrefix .. "_CORNER_TOP_PREFAB")
registerDefaultBuildingPart(_CommonWindowPrefix .. "_CORNER_TOP")

StoneGate:registerAssetId("models/stoneDecoration/corner.fbx/Prefab/corner/step_1_Corner_Tiling1Part", _CommonWindowPrefix .. "_CORNER_TILING1_PREFAB")
registerDefaultBuildingPart(_CommonWindowPrefix .. "_CORNER_TILING1")

for i=11,20 do
    StoneGate:registerAssetId("models/stoneDecoration/corner.fbx/Prefab/corner/step_2_Corner_Tiling" .. i .. "Part", _CommonWindowPrefix .. "_CORNER_TILING" .. i .. "_PREFAB")
    registerDefaultBuildingPart(_CommonWindowPrefix .. "_CORNER_TILING" .. i)
end

function registerCorner()
    -- Register Small Squared Tower prefab nodes
    StoneGate:registerAssetId("models/stoneDecoration/corner.fbx/Prefab/corner/step_0_Corner_RootPart", _CommonWindowPrefix .. "_CORNER_ROOT_PREFAB")

    -- Register the stone gate set small squared tower root part
    StoneGate:registerAsset({
	DataType = "BUILDING_PART",
	Id = _CommonWindowPrefix .. "_CORNER_ROOT_PART",
	Name = _CommonWindowPrefix .. "_CORNER_ROOT_NAME",
	Description = _CommonWindowPrefix .. "_CORNER_ROOT_DESC",
	Category = StoneGateSetPrefix .. "_DECORATION_PARTSETLIST_NAME",
        BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {0.1, 0.1} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } }
        }},
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _CommonWindowPrefix .. "_CORNER_ROOT_PREFAB",
		EndPart = _CommonWindowPrefix .. "_CORNER_TOP_PART",
		FillerList = {
			_CommonWindowPrefix .. "_CORNER_TILING20_PART",
			_CommonWindowPrefix .. "_CORNER_TILING19_PART",
			_CommonWindowPrefix .. "_CORNER_TILING18_PART",
			_CommonWindowPrefix .. "_CORNER_TILING17_PART",
			_CommonWindowPrefix .. "_CORNER_TILING16_PART",
			_CommonWindowPrefix .. "_CORNER_TILING15_PART",
			_CommonWindowPrefix .. "_CORNER_TILING14_PART",
			_CommonWindowPrefix .. "_CORNER_TILING13_PART",
			_CommonWindowPrefix .. "_CORNER_TILING12_PART",
			_CommonWindowPrefix .. "_CORNER_TILING11_PART"
                },
		BasementFillerList = {
			_CommonWindowPrefix .. "_CORNER_TILING1_PART"
         	},
		MinimumScale = 0,
		IsVertical = true,
                MiniatureConfig = {
                        DataType = "BUILDING_MINIATURE_CONFIG",
                        ClipUnderGround = false
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		ResourceNeededList = {{ -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _NoSandbox*1 }
		}}
	}
    })
end

registerCorner()
